==> jc-1.4.0.tar.gz: soot/relations/Relation__24RelationIterator.h <==
// class soot.relations.Relation$RelationIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 23e4886ce10b9a56 soot_relations_Relation__24RelationIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_relations_Relation__24RelationIterator_H_
#define _JC_soot_relations_Relation__24RelationIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_relations_Relation$object;
struct _jc_soot_util_Numberer$object;

// Typedefs
typedef struct _jc_soot_relations_Relation__24RelationIterator$sub_refs	_jc_soot_relations_Relation__24RelationIterator$sub_refs;
typedef struct _jc_soot_relations_Relation__24RelationIterator$sub_nonrefs	_jc_soot_relations_Relation__24RelationIterator$sub_nonrefs;
typedef struct _jc_soot_relations_Relation__24RelationIterator$refs	_jc_soot_relations_Relation__24RelationIterator$refs;
typedef struct _jc_soot_relations_Relation__24RelationIterator$nonrefs	_jc_soot_relations_Relation__24RelationIterator$nonrefs;
typedef struct _jc_soot_relations_Relation__24RelationIterator$object	_jc_soot_relations_Relation__24RelationIterator$object;

typedef const struct _jc_soot_relations_Relation__24RelationIterator$vmethods	_jc_soot_relations_Relation__24RelationIterator$vmethods;
typedef const struct _jc_soot_relations_Relation__24RelationIterator$vtable	_jc_soot_relations_Relation__24RelationIterator$vtable;
typedef const struct _jc_soot_relations_Relation__24RelationIterator$vtype	_jc_soot_relations_Relation__24RelationIterator$vtype;

// Constructors
extern void _jc_soot_relations_Relation__24RelationIterator$method$_init$10aa2015ce6b6b72(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *, struct _jc_soot_relations_Relation$object *, struct _jc_int_array *, struct _jc_soot_util_Numberer$object *);

// Virtual methods
extern jboolean _jc_soot_relations_Relation__24RelationIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_relations_Relation__24RelationIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *);
extern void _jc_soot_relations_Relation__24RelationIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_relations_Relation__24RelationIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_relations_Relation__24RelationIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_relations_Relation__24RelationIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_relations_Relation__24RelationIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *);
};

// Vtable
struct _jc_soot_relations_Relation__24RelationIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_relations_Relation__24RelationIterator$vmethods	soot_relations_Relation__24RelationIterator;
};

// Vtype
struct _jc_soot_relations_Relation__24RelationIterator$vtype {
	_jc_type			type;
	_jc_soot_relations_Relation__24RelationIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_relations_Relation__24RelationIterator$sub_refs {
	_jc_int_array	*sats;
	struct _jc_soot_util_Numberer$object	*numberer;
	struct _jc_soot_relations_Relation$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_relations_Relation__24RelationIterator$refs {
    _jc_soot_relations_Relation__24RelationIterator$sub_refs	soot_relations_Relation__24RelationIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_relations_Relation__24RelationIterator$sub_nonrefs {
	jint	cur;
};

// Non-reference instance fields (object)
struct _jc_soot_relations_Relation__24RelationIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_relations_Relation__24RelationIterator$sub_nonrefs	soot_relations_Relation__24RelationIterator;
};

// Object instance structure
struct _jc_soot_relations_Relation__24RelationIterator$object {
	_jc_soot_relations_Relation__24RelationIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_relations_Relation__24RelationIterator$vtype	*vtype;
	_jc_soot_relations_Relation__24RelationIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_relations_Relation__24RelationIterator$vtype _jc_soot_relations_Relation__24RelationIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_relations_Relation__24RelationIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_relations_Relation__24RelationIterator$class_object;

#endif	/* _JC_soot_relations_Relation__24RelationIterator_H_ */

==> jc-1.4.6.tar.gz: soot/relations/Relation__24RelationIterator.h <==
// class soot.relations.Relation$RelationIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 23e4886ce10b9a56 soot_relations_Relation__24RelationIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_relations_Relation__24RelationIterator_H_
#define _JC_soot_relations_Relation__24RelationIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_relations_Relation$object;
struct _jc_soot_util_Numberer$object;

// Typedefs
typedef struct _jc_soot_relations_Relation__24RelationIterator$sub_refs	_jc_soot_relations_Relation__24RelationIterator$sub_refs;
typedef struct _jc_soot_relations_Relation__24RelationIterator$sub_nonrefs	_jc_soot_relations_Relation__24RelationIterator$sub_nonrefs;
typedef struct _jc_soot_relations_Relation__24RelationIterator$refs	_jc_soot_relations_Relation__24RelationIterator$refs;
typedef struct _jc_soot_relations_Relation__24RelationIterator$nonrefs	_jc_soot_relations_Relation__24RelationIterator$nonrefs;
typedef struct _jc_soot_relations_Relation__24RelationIterator$object	_jc_soot_relations_Relation__24RelationIterator$object;

typedef const struct _jc_soot_relations_Relation__24RelationIterator$vmethods	_jc_soot_relations_Relation__24RelationIterator$vmethods;
typedef const struct _jc_soot_relations_Relation__24RelationIterator$vtable	_jc_soot_relations_Relation__24RelationIterator$vtable;
typedef const struct _jc_soot_relations_Relation__24RelationIterator$vtype	_jc_soot_relations_Relation__24RelationIterator$vtype;

// Constructors
extern void _jc_soot_relations_Relation__24RelationIterator$method$_init$10aa2015ce6b6b72(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *, struct _jc_soot_relations_Relation$object *, struct _jc_int_array *, struct _jc_soot_util_Numberer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_relations_Relation__24RelationIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_relations_Relation__24RelationIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_relations_Relation__24RelationIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_relations_Relation__24RelationIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_relations_Relation__24RelationIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_relations_Relation__24RelationIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_relations_Relation__24RelationIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_relations_Relation__24RelationIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_relations_Relation__24RelationIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_relations_Relation__24RelationIterator$vmethods	soot_relations_Relation__24RelationIterator;
};

// Vtype
struct _jc_soot_relations_Relation__24RelationIterator$vtype {
	_jc_type			type;
	_jc_soot_relations_Relation__24RelationIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_relations_Relation__24RelationIterator$sub_refs {
	_jc_int_array	*sats;
	struct _jc_soot_util_Numberer$object	*numberer;
	struct _jc_soot_relations_Relation$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_relations_Relation__24RelationIterator$refs {
    _jc_soot_relations_Relation__24RelationIterator$sub_refs	soot_relations_Relation__24RelationIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_relations_Relation__24RelationIterator$sub_nonrefs {
	jint	cur;
};

// Non-reference instance fields (object)
struct _jc_soot_relations_Relation__24RelationIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_relations_Relation__24RelationIterator$sub_nonrefs	soot_relations_Relation__24RelationIterator;
};

// Object instance structure
struct _jc_soot_relations_Relation__24RelationIterator$object {
	_jc_soot_relations_Relation__24RelationIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_relations_Relation__24RelationIterator$vtype	*vtype;
	_jc_soot_relations_Relation__24RelationIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_relations_Relation__24RelationIterator$vtype _jc_soot_relations_Relation__24RelationIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_relations_Relation__24RelationIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_relations_Relation__24RelationIterator$class_object;

#endif	/* _JC_soot_relations_Relation__24RelationIterator_H_ */
